package main

import (
	"net/http"
	"os"

	"git.schreifuchs.ch/schreifuchs/ng-blog/backend/auth"
	"git.schreifuchs.ch/schreifuchs/ng-blog/backend/blog"
	"git.schreifuchs.ch/schreifuchs/ng-blog/backend/cors"
	"git.schreifuchs.ch/schreifuchs/ng-blog/backend/model"
	"github.com/gorilla/mux"
)

func main() {
	user, ok := os.LookupEnv("USERNAME")
	if !ok {
		user = "admin"
	}
	password, ok := os.LookupEnv("PASSWORD")
	if !ok {
		password = "admin"
	}
	secret, ok := os.LookupEnv("SECRET")
	if !ok {
		secret = "Foo"
	}

	db := model.Init()
	blg := blog.New(db)
	r := mux.NewRouter()
	r.Handle("/login", auth.Login(user, password, []byte(secret))).Methods("POST")
	r.Handle("/posts", auth.Authenticated([]byte(secret))(blg.CreatePost)).Methods("POST")
	r.Handle("/posts", http.HandlerFunc(blg.GetAllPosts)).Methods("GET")

	r.Use(cors.HandlerForOrigin("*"))

	http.ListenAndServe(":8080", r)
}
